@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class ImportExportProgressIndicatorConsole : public ImportExportProgressIndicato
 {
     Q_OBJECT
 public:
-    explicit ImportExportProgressIndicatorConsole(QObject *parent = Q_NULLPTR);
+    explicit ImportExportProgressIndicatorConsole(QObject *parent = nullptr);
     ~ImportExportProgressIndicatorConsole();
 
 private:
