@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,9 +24,9 @@
 #include "MailCommon/FilterManager"
 #include "MailCommon/FilterImporterExporter"
 #include "MailCommon/MailUtil"
-#include "PimCommon/CreateResource"
+#include <PimCommonAkonadi/CreateResource>
 
-#include <MailTransport/mailtransport/transportmanager.h>
+#include <mailtransport/transportmanager.h>
 
 #include <KIdentityManagement/kidentitymanagement/identitymanager.h>
 #include <KIdentityManagement/kidentitymanagement/identity.h>
@@ -112,7 +112,8 @@ void ImportMailJob::slotNextStep()
 
 void ImportMailJob::searchAllMailsFiles(const KArchiveDirectory *dir, const QString &prefix)
 {
-    Q_FOREACH (const QString &entryName, dir->entries()) {
+    const QStringList lst = dir->entries();
+    for (const QString &entryName : lst) {
         const KArchiveEntry *entry = dir->entry(entryName);
         if (entry && entry->isDirectory()) {
             const QString newPrefix = (prefix.isEmpty() ? prefix : prefix + QLatin1Char('/')) + entryName;
@@ -130,7 +131,8 @@ void ImportMailJob::searchAllMailsFiles(const KArchiveDirectory *dir, const QStr
 
 void ImportMailJob::storeMailArchiveResource(const KArchiveDirectory *dir, const QString &prefix)
 {
-    Q_FOREACH (const QString &entryName, dir->entries()) {
+    const QStringList lst = dir->entries();
+    for (const QString &entryName : lst) {
         const KArchiveEntry *entry = dir->entry(entryName);
         if (entry && entry->isDirectory()) {
             const KArchiveDirectory *resourceDir = static_cast<const KArchiveDirectory *>(entry);
@@ -138,7 +140,7 @@ void ImportMailJob::storeMailArchiveResource(const KArchiveDirectory *dir, const
             if (lst.count() >= 2) {
                 const QString archPath(prefix + QLatin1Char('/') + entryName + QLatin1Char('/'));
                 resourceFiles files;
-                Q_FOREACH (const QString &name, lst) {
+                for (const QString &name : lst) {
                     if (name.endsWith(QLatin1String("rc")) &&
                             (name.contains(QStringLiteral("akonadi_mbox_resource_")) ||
                              name.contains(QStringLiteral("akonadi_mixedmaildir_resource_")) ||
@@ -184,7 +186,7 @@ void ImportMailJob::restoreTransports()
             }
 
             const QStringList transportList = transportConfig->groupList().filter(QRegularExpression(QStringLiteral("Transport \\d+")));
-            Q_FOREACH (const QString &transport, transportList) {
+            for (const QString &transport : transportList) {
                 KConfigGroup group = transportConfig->group(transport);
                 const int transportId = group.readEntry(QStringLiteral("id"), -1);
                 MailTransport::Transport *mt = MailTransport::TransportManager::self()->createTransport();
@@ -397,9 +399,6 @@ void ImportMailJob::restoreResources()
                     if (cache.hasKey(QStringLiteral("AutomaticExpungeEnabled"))) {
                         settings.insert(QStringLiteral("AutomaticExpungeEnabled"), cache.readEntry("AutomaticExpungeEnabled", true));
                     }
-                    if (cache.hasKey(QLatin1String(""))) {
-                        settings.insert(QLatin1String(""), cache.readEntry(""));
-                    }
                     if (cache.hasKey(QStringLiteral("DisconnectedModeEnabled"))) {
                         settings.insert(QStringLiteral("DisconnectedModeEnabled"), cache.readEntry("DisconnectedModeEnabled", false));
                     }
@@ -609,7 +608,7 @@ void ImportMailJob::restoreConfig()
             const QString filterFileName(mTempDirName + QLatin1Char('/') + QLatin1String("filters"));
             KSharedConfig::Ptr filtersConfig = KSharedConfig::openConfig(filterFileName);
             const QStringList filterList = filtersConfig->groupList().filter(QRegularExpression(QStringLiteral("Filter #\\d+")));
-            Q_FOREACH (const QString &filterStr, filterList) {
+            for (const QString &filterStr : filterList) {
                 KConfigGroup group = filtersConfig->group(filterStr);
                 const QString accountStr(QStringLiteral("accounts-set"));
                 if (group.hasKey(accountStr)) {
@@ -617,7 +616,7 @@ void ImportMailJob::restoreConfig()
                     if (!accounts.isEmpty()) {
                         const QStringList lstAccounts = accounts.split(QLatin1Char(','));
                         QStringList newLstAccounts;
-                        Q_FOREACH (const QString &acc, lstAccounts) {
+                        for (const QString &acc : lstAccounts) {
                             if (mHashResources.contains(acc)) {
                                 newLstAccounts.append(mHashResources.value(acc));
                             } else {
@@ -811,19 +810,20 @@ void ImportMailJob::restoreConfig()
     restoreConfigFile(QStringLiteral("kwatchgnupgrc"));
     restoreConfigFile(QStringLiteral("pimpluginsrc"));
     //Restore notify file
-    QStringList lstNotify;
-    lstNotify << QStringLiteral("akonadi_mailfilter_agent.notifyrc")
-              << QStringLiteral("akonadi_sendlater_agent.notifyrc")
-              << QStringLiteral("akonadi_archivemail_agent.notifyrc")
-              << QStringLiteral("kmail2.notifyrc")
-              << QStringLiteral("akonadi_newmailnotifier_agent.notifyrc")
-              << QStringLiteral("akonadi_maildispatcher_agent.notifyrc")
-              << QStringLiteral("akonadi_followupreminder_agent.notifyrc")
-              << QStringLiteral("messageviewer.notifyrc")
-              << QStringLiteral("storageservicemanager.notifyrc");
+    const QStringList lstNotify = {
+        QStringLiteral("akonadi_mailfilter_agent.notifyrc"),
+        QStringLiteral("akonadi_sendlater_agent.notifyrc"),
+        QStringLiteral("akonadi_archivemail_agent.notifyrc"),
+        QStringLiteral("kmail2.notifyrc"),
+        QStringLiteral("akonadi_newmailnotifier_agent.notifyrc"),
+        QStringLiteral("akonadi_maildispatcher_agent.notifyrc"),
+        QStringLiteral("akonadi_followupreminder_agent.notifyrc"),
+        QStringLiteral("messageviewer.notifyrc"),
+        QStringLiteral("storageservicemanager.notifyrc")
+    };
 
     //We can't merge it.
-    Q_FOREACH (const QString &filename, lstNotify) {
+    for (const QString &filename : lstNotify) {
         restoreConfigFile(filename);
     }
 
@@ -854,7 +854,8 @@ void ImportMailJob::importSimpleFilesInDirectory(const QString &relativePath)
     const KArchiveEntry *autocorrectionEntry  = mArchiveDirectory->entry(Utils::dataPath() + relativePath);
     if (autocorrectionEntry && autocorrectionEntry->isDirectory()) {
         const KArchiveDirectory *autoCorrectionDir = static_cast<const KArchiveDirectory *>(autocorrectionEntry);
-        Q_FOREACH (const QString &entryName, autoCorrectionDir->entries()) {
+        const QStringList lst = autoCorrectionDir->entries();
+        for (const QString &entryName : lst) {
             const KArchiveEntry *entry = autoCorrectionDir->entry(entryName);
             if (entry && entry->isFile()) {
                 const KArchiveFile *autocorrectionFile = static_cast<const KArchiveFile *>(entry);
@@ -892,7 +893,7 @@ void ImportMailJob::restoreIdentity()
             const int defaultIdentity = general.readEntry(QStringLiteral("Default Identity"), -1);
 
             const QStringList identityList = identityConfig->groupList().filter(QRegularExpression(QStringLiteral("Identity #\\d+")));
-            Q_FOREACH (const QString &identityStr, identityList) {
+            for (const QString &identityStr : identityList) {
                 KConfigGroup group = identityConfig->group(identityStr);
                 int oldUid = -1;
                 const QString uidStr(QStringLiteral("uoid"));
@@ -1049,7 +1050,7 @@ void ImportMailJob::importFolderArchiveConfig(const KArchiveFile *archiveconfigu
 
     const QStringList archiveList = archiveConfig->groupList().filter(QRegularExpression(QStringLiteral("FolderArchiveAccount ")));
 
-    Q_FOREACH (const QString &str, archiveList) {
+    for (const QString &str : archiveList) {
         KConfigGroup oldGroup = archiveConfig->group(str);
         const Akonadi::Collection::Id id = convertPathToId(oldGroup.readEntry(QStringLiteral("topLevelCollectionId")));
         if (id != -1) {
@@ -1065,7 +1066,7 @@ void ImportMailJob::copyArchiveMailAgentConfigGroup(KSharedConfig::Ptr archiveCo
     //adapt id
     const QString archiveGroupPattern = QStringLiteral("ArchiveMailCollection ");
     const QStringList archiveList = archiveConfigOrigin->groupList().filter(archiveGroupPattern);
-    Q_FOREACH (const QString &str, archiveList) {
+    for (const QString &str : archiveList) {
         const QString path = str.right(str.length() - archiveGroupPattern.length());
         if (!path.isEmpty()) {
             KConfigGroup oldGroup = archiveConfigOrigin->group(str);
@@ -1092,7 +1093,7 @@ void ImportMailJob::importTemplatesConfig(const KArchiveFile *templatesconfigura
     //adapt id
     const QString templateGroupPattern = QStringLiteral("Templates #");
     const QStringList templateList = templateConfig->groupList().filter(templateGroupPattern);
-    Q_FOREACH (const QString &str, templateList) {
+    for (const QString &str : templateList) {
         const QString path = str.right(str.length() - templateGroupPattern.length());
         if (!path.isEmpty()) {
             KConfigGroup oldGroup = templateConfig->group(str);
@@ -1107,7 +1108,7 @@ void ImportMailJob::importTemplatesConfig(const KArchiveFile *templatesconfigura
     //adapt identity
     const QString templateGroupIdentityPattern = QStringLiteral("Templates #IDENTITY_");
     const QStringList templateListIdentity = templateConfig->groupList().filter(templateGroupIdentityPattern);
-    Q_FOREACH (const QString &str, templateListIdentity) {
+    for (const QString &str : templateListIdentity) {
         bool found = false;
         const int identity = str.rightRef(str.length() - templateGroupIdentityPattern.length()).toInt(&found);
         if (found) {
@@ -1137,7 +1138,7 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
     //adapt folder id
     const QString folderGroupPattern = QStringLiteral("Folder-");
     const QStringList folderList = kmailConfig->groupList().filter(folderGroupPattern);
-    Q_FOREACH (const QString &str, folderList) {
+    for (const QString &str : folderList) {
         const QString path = str.right(str.length() - folderGroupPattern.length());
         if (!path.isEmpty()) {
             KConfigGroup oldGroup = kmailConfig->group(str);
@@ -1152,10 +1153,10 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
     const QString accountOrder(QStringLiteral("AccountOrder"));
     if (kmailConfig->hasGroup(accountOrder)) {
         KConfigGroup group = kmailConfig->group(accountOrder);
-        QStringList orderList = group.readEntry(QStringLiteral("order"), QStringList());
+        const QStringList orderList = group.readEntry(QStringLiteral("order"), QStringList());
         QStringList newOrderList;
         if (!orderList.isEmpty()) {
-            Q_FOREACH (const QString &account, orderList) {
+            for (const QString &account : orderList) {
                 if (mHashResources.contains(account)) {
                     newOrderList.append(mHashResources.value(account));
                 } else {
@@ -1209,7 +1210,7 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
 
     const QString resourceGroupPattern = QStringLiteral("Resource ");
     const QStringList resourceList = kmailConfig->groupList().filter(resourceGroupPattern);
-    Q_FOREACH (const QString &str, resourceList) {
+    for (const QString &str : resourceList) {
         const QString res = str.right(str.length() - resourceGroupPattern.length());
         if (!res.isEmpty()) {
             KConfigGroup oldGroup = kmailConfig->group(str);
