@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,7 +20,7 @@
 #include "importnotesjob.h"
 #include "archivestorage.h"
 
-#include "PimCommon/CreateResource"
+#include <PimCommonAkonadi/CreateResource>
 
 #include <KArchive>
 #include <KLocalizedString>
